Installation
============

To install ``kelp``, run::

    pip install git+https://github.com/bmorris3/kelp.git

Any installation issues can be reported
`here <https://github.com/bmorris3/kelp/issues>`_.

Mac OS X Catalina
-----------------

There is a known issue on Mac OS X Catalina when using the XCode Command Line
Tools v12. This can be avoided by downgrading to Command Line Tools v11.5.
